//Bibliothek zum Aufbau einer WiFi Verbindung
#include <ESP8266WiFi.h>
#include <ESP8266WebServer.h>
#include <WEMOS_SHT3X.h>

#include "htmlcode.h"

//SSID aus dem Router
const char* ssid = "FRITZBox7590GI24";
//Passwort für den Zugang zum WLAN
const char* password = "22894580214767401850";

//Aufbau eines Webservers mit HttpPort 80
ESP8266WebServer server(80);

//Luftqualitätssensor MQ-2 am analogen Pin A0
#define MQ2Pin A0

//Objekt instanziieren vom Typ SHT3X mit
//der I2C Adresse 0x44
SHT3X sht30(0x44);

//Felder für die Temperatur & Luftfeuchtigkeit
String temperatur = "0";
String luftfeuchtigkeit = "0";

void setupWiFi() {
  //Ausgabe der SSID auf der seriellen Schnittstelle
  Serial.print("Aufbau der WiFi Verbindung zu ");
  Serial.print(ssid);
  Serial.print(" ");
  WiFi.begin(ssid, password);
  int index = 0;
  //Warten bis die Verbindung aufgebaut wurde,
  //oder 10 Versuche gescheitert sind.
  while (WiFi.status() != WL_CONNECTED || index < 11) {
    delay(500);
    index++;  //incrementieren des Indexes
    Serial.print(".");
  }
  Serial.println();
  //Wenn die Verbindung erfolgreich aufgebaut wurde,
  //dann soll die IP-Adresse ausgegeben werden.
  if (WiFi.status() == WL_CONNECTED) {
    Serial.print("IP-Adresse: ");
    Serial.println(WiFi.localIP().toString());
    //Server starten
    server.begin();
  }
}

void setup() {
  //begin der seriellen Kommunikation
  Serial.begin(9600);
  //Aufrufen der Funktion setupWiFi
  //zum Aufbau der WiFi-Verbindung.
  setupWiFi();

  //definieren das der Pin des
  //Luftqualitätssensors als Eingang dient.
  pinMode(MQ2Pin, INPUT);

  //Wenn der Benutzer im Browser die Adresse
  //http://<IP-Adresse>/dashboard eingibt, dann
  //soll die Funktion callDashboard aufgerufen werden
  server.on("/dashboard", callDashboard);
}

void callDashboard() {

  //lesen der Sensordaten vom SHT30 Sensor
  if (sht30.get() == 0) {
    //Auslesen der Daten und gleichzeitig formatieren mit
    //zwei Nachkommastellen.
    temperatur = String(sht30.cTemp, 2);
    luftfeuchtigkeit = String(sht30.humidity, 2);
  }

  //Auslesen des aktuellen analogen Wertes des Luftqualitätssensors
  String luftqualitaet = String(analogRead(MQ2Pin), DEC);

  //Aufbau der Webseite...
  String htmlContent = "";
  htmlContent += part1;
  htmlContent += part2;
  htmlContent += temperatur;
  htmlContent += part3;
  htmlContent += luftfeuchtigkeit;
  htmlContent += part4;
  htmlContent += luftqualitaet;
  htmlContent += part5;
  //Absenden der generierten Webseite
  server.send(200, "text/html", htmlContent);
}

void loop() {
  server.handleClient();
}
